@@ -83,6 +83,11 @@ FF_MAYBE_UNUSED static void getUbuntuFlavour(FFOSResult* result)
         ffStrbufSetS(&result->versionID, result->prettyName.chars + strlen("Rhino Linux "));
         return;
     }
+    else if(ffStrbufStartsWithS(&result->prettyName, "VanillaOS "))
+    {
+        ffStrbufSetS(&result->id, "vanilla");
+        ffStrbufSetS(&result->idLike, "ubuntu");
+    }
 
     if(ffStrContains(xdgConfigDirs, "kde") || ffStrContains(xdgConfigDirs, "plasma") || ffStrContains(xdgConfigDirs, "kubuntu"))
     {
@@ -226,6 +231,24 @@ FF_MAYBE_UNUSED static bool detectDebianDerived(FFOSResult* result)
         ffStrbufSetF(&result->prettyName, "Proxmox VE %s", result->versionID.chars);
         return true;
     }
+    else if (ffStrbufContainS(&instance.state.platform.sysinfo.release, "+rpt-rpi-"))
+    {
+        // Raspberry Pi OS
+        ffStrbufSetS(&result->id, "raspbian");
+        ffStrbufSetS(&result->idLike, "debian");
+        ffStrbufSetS(&result->name, "Raspberry Pi OS");
+        ffStrbufSetS(&result->prettyName, "Raspberry Pi OS");
+        return true;
+    }
+    else if (ffStrbufEndsWithS(&instance.state.platform.sysinfo.release, "+truenas"))
+    {
+        // TrueNAS Scale
+        ffStrbufSetS(&result->id, "truenas-scale");
+        ffStrbufSetS(&result->idLike, "debian");
+        ffStrbufSetS(&result->name, "TrueNAS Scale");
+        ffStrbufSetS(&result->prettyName, "TrueNAS Scale");
+        return true;
+    }
     else
     {
         // Hack for MX Linux. See #847
@@ -281,8 +304,19 @@ static void detectOS(FFOSResult* os)
     parseOsRelease(FASTFETCH_TARGET_DIR_ETC "/os-release", os);
     if (os->id.length == 0 || os->version.length == 0 || os->prettyName.length == 0 || os->codename.length == 0)
         parseLsbRelease(FASTFETCH_TARGET_DIR_ETC "/lsb-release", os);
-    if (os->id.length == 0 || os->name.length > 0 || os->prettyName.length > 0)
+    if (os->id.length == 0 || os->name.length == 0 || os->prettyName.length == 0)
         parseOsRelease(FASTFETCH_TARGET_DIR_USR "/lib/os-release", os);
+    if (os->id.length == 0 && os->name.length == 0 && os->prettyName.length == 0)
+    {
+        // HarmonyOS has no os-release file
+        if (ffStrbufEqualS(&instance.state.platform.sysinfo.name, "HarmonyOS"))
+        {
+            ffStrbufSetS(&os->id, "harmonyos");
+            ffStrbufSetS(&os->idLike, "harmonyos");
+            ffStrbufSetS(&os->name, "HarmonyOS");
+            ffStrbufSetS(&os->prettyName, "HarmonyOS");
+        }
+    }
 }
 
 void ffDetectOSImpl(FFOSResult* os)
